package com.informationkinematics.imsforward;

import java.util.*;
import javax.mail.*;

/**
 * Title:        Authentication<br>
 * Description:  Handles the user's login procedure on the POP3 host.<br>
 * Copyright:    Copyright (c) 2001 by Information Kinematics under GNU General Public License
 *               (see package description for more information)<br>
 * Company:      Information Kinematics<br>
 * @author Florian Steinsiepe, Adrian Zaugg
 * @version 0.9.2
 */

public class Authentication
{
	private int iNewMailCount;
	private String sUserName, sPassWord;

	/**
	 * Authenticates the user on the POP3 host and receives the number of
	 * mails residing in the related inbox.<br>
	 * The exceptions that may be thrown are specific to a certain
	 * problem (wrong authentication data, mailbox locked, host not
	 * available or hostname incorrect, transportation error).
	 *
	 * @param sUserName java.lang.String
	 * @param sPassWord java.lang.String
	 * @param sPOP3Host java.lang.String
	 */
	public Authentication(String sUserName, String sPassWord, String sPOP3Host)
		    throws AuthenticationFailedException, FolderClosedException,
				    NoSuchProviderException, MessagingException
	{
		this.sUserName = sUserName;
		this.sPassWord = sPassWord;

		Message [] message;
		// set session properties
		Properties props = System.getProperties();
		props.put("mail.pop3.host", sPOP3Host);
		// get authenticator
		MyAuthenticator auth = new MyAuthenticator();
		// get session
		Session session = Session.getInstance(props, auth);
		// use session to provoke an authenticationFaliledExeption or get numbers of new mails
		Store store = session.getStore("pop3");
		store.connect();
		Folder folder = store.getFolder("INBOX");
		folder.open(Folder.READ_ONLY);
		message = folder.getMessages();
		iNewMailCount = message.length;
		folder.close(false);
		store.close();
	}

	/**
	 * Returns the number of mails that reside in the user's inbox.
	 *
	 * @return int
	 */
	public int getNewMailCount()
	{
		return iNewMailCount;
	}

	/**
	 * This implementation of Authenticator overrides the callback
	 * method which returns the username / password pair.
	 */
	public class MyAuthenticator extends Authenticator
	{
		/**
		 * Returns the class which contains the username and the
		 * password to authenticate the user on the POP3 host.
		 *
		 * @return javax.mail.PasswordAuthentication
		 */
		public PasswordAuthentication getPasswordAuthentication()
		{
			return new PasswordAuthentication(sUserName, sPassWord);
		}
	}
}