package com.informationkinematics.imsforward;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 * Title:        Showdown<br>
 * Description:  Controls the writing of the mail server's control file and shows the final
 *               status screen of the IMSForward application.<br>
 * Copyright:    Copyright (c) 2001 by Information Kinematics under GNU General Public License
 *               (see package description for more information)<br>
 * Company:      Information Kinematics<br>
 * @author Florian Steinsiepe, Adrian Zaugg
 * @version 0.9.2
 */

public class Showdown extends Littles
{
	/**
	 * doGet is inactive to avoid the possibility to bypass the IMSForward's security
	 * checks which are performed in earlier steps.
	 *
	 * @param req javax.servlet.http.HttpServletRequest
	 * @param res javax.servlet.http.HttpServletResponse
	 */
    public void doGet(HttpServletRequest req, HttpServletResponse res)  throws ServletException, IOException
    {
        // doGet, just forget.
        // ...as a filewriting takes place and path is overhanded, it would be risky to accept a doGet!
    }

	/**
	 * doPost reads the client's input, formats the parameters for the mail server's control file,
	 * writes the file and shows the final screen.
	 *
	 * @param req javax.servlet.http.HttpServletRequest
	 * @param res javax.servlet.http.HttpServletResponse
	 */
    public void doPost(HttpServletRequest req, HttpServletResponse res)  throws ServletException, IOException
    {
        // Get username, newmailcount, imspath.
        int iNewMailCount = toInt (req.getParameter("newmailcount"));
        String sUserName = req.getParameter("username");
        String sIMSPath = req.getParameter("imspath");
        String sOutput = "";

        // Digest SetupWindow: Read its values and build up IMS.CTL resp. rename it.
        String sEmail = req.getParameter("forwardaddress");
        boolean bForwardingIsActive = isTrueOrFalse(req.getParameter("activateforwarding")),
                bDiscard = isTrueOrFalse(req.getParameter("discard"));

        // Do not activate forwarding if no email address is set!
        if (sEmail.length()==0)
           bForwardingIsActive = false;

        // Write IMS.CTL resp. IMS.CTL.inactive .
        File fIMSFileA = new File(sIMSPath + IMSFILE_ACTIVE);
        File fIMSFileI = new File(sIMSPath + IMSFILE_INACTIVE);
        CTLIOController ioC = new CTLIOController();
        if (bForwardingIsActive)
        {
            try {
              ioC.writeCTLFile (fIMSFileA, sEmail, bDiscard);
            } catch (IOException e) {
                sOutput += "The file \"" + IMSFILE_ACTIVE +
					    "\" may be locked and could not be updated.<br>Please try again now or later.<br>";
            }
        }
        else
        {
            try {
                ioC.writeCTLFile(fIMSFileI, sEmail, bDiscard);
            } catch (IOException e) {
                sOutput += "The file \"" + IMSFILE_INACTIVE +
					    "\" may be locked and could not be updated.<br>Please try again now or later.<br>";
            }
            try {
                if (fIMSFileA.exists())
                    ioC.deleteFile(fIMSFileA);
            } catch (IOException e) {
                sOutput += "Sorry, because the file \"" + IMSFILE_ACTIVE +
					    "\" may be locked and could not be deleted, your forwarding remains active.<br>Please try again now or later.<br>";
            }
        }

        // Show exit screen.
        if (sOutput.equals(""))
            sOutput = "<h4>Update successful:</h4><br><br><font size=\"-1\">Forwarding is <em>" +
                      ((bForwardingIsActive) ? "" : "in") + "active</em>...<br>" +
                      ((bForwardingIsActive) ? "to email address: <em>" + sEmail + "</em>": "") + "<br>" +
                      ((bForwardingIsActive) ? ((bDiscard) ? "Mails will be discarded." : "Mails do stay on the server.") : "") + "<br><br>" +
                      ((bForwardingIsActive && (iNewMailCount == 1)) ? "<i>The new messages already on the server won't be forwarded.</i>" : "") +
                      ((bForwardingIsActive && (iNewMailCount > 1)) ? "<i>Those " + iNewMailCount + " new messages on the server won't be forwarded.</i>" : "") + "</font>";
        else
            sOutput = "<h4>Error occurred:</h4><br><br>" + sOutput;
        res.setContentType("text/html");
        PrintWriter out = res.getWriter();
        out.println(HTMLCode.SHOWDOWN_1 + sOutput +
                    HTMLCode.SHOWDOWN_2);
        out.close();
    }

	/**
	 * Returns true if s equals "checked" (case-insensitive), else false.
	 *
	 * @param s java.lang.String
	 * @return boolean
	 */
    private boolean isTrueOrFalse(String s)
    {
        if ((s == null ) || !s.toLowerCase().equals("checked"))
            return false;
        else
            return true;
    }

	/**
	 * Parses s into an int and returns it. If this fails, an exception is thrown.
	 *
	 * @param s java.lang.String
	 * @return int
	 */
    private int toInt(String s)
    {
		Integer i = new Integer(0);
		i = i.decode(s);
		return i.intValue();
    }
}