package com.informationkinematics.imsforward;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

/**
 * Title:        Littles<br>
 * Description:  This is the abstract superclass of each IMSForward GUI servlet, providing a set of
 *               helpful little tools and storing constants.<br>
 * Copyright:    Copyright (c) 2001 by Information Kinematics under GNU General Public License
 *               (see package description for more information)<br>
 * Company:      Information Kinematics<br>
 * @author Florian Steinsiepe, Adrian Zaugg
 * @version 0.9.2
 */


public abstract class Littles extends HttpServlet
{
	/** File name constants for IMS's controller file (active and inactive). */
	protected static final String
		IMSFILE_ACTIVE = "ims.ctl",
		IMSFILE_INACTIVE = "ims.ctl.inactive";

	/** Not yet parsed IMSPath, is set in readIMSForwardProperties() */
	private String sIMSPathFromRB;

	/** POP3 Server address, accessible for extending classes */
	protected String sPOP3Host;

	/**
	 *  Servlet initialization. Reads the project's parameter file.
	 */
	public void init() throws ServletException
	{
	    readIMSForwardProperties();
	}

	/**
	 *  Read parameter file and extract the IMS path into sIMSPathFromRB.
	 */
	private void readIMSForwardProperties ()
	{
		// Read parameterfile
		ResourceBundle rb = ResourceBundle.getBundle("com.informationkinematics.imsforward.imsforward");
		sIMSPathFromRB = rb.getString("IMSPath").trim();
		sPOP3Host = rb.getString("POP3Host").trim();
	}

	/**
	 * Replaces the environment variables in sIMSPathFromRB with their actual values, and
	 * %IMSMAILSERVERUSERNAME% with the passed string. If the user's inbox folder isn't
	 * found, an IOException is thrown.
	 *
	 * @param sUserName java.lang.String - replaces %IMSMAILSERVERUSERNAME% in sIMSPathFromRB
	 * @return java.lang.String - the absolute path to the user's IMS mail server control file
	 */
	protected String getIMSPath(String sUserName) throws IOException, EnvVarNotFoundException
	{
		String sIMSPath = "";

		//check for environment variables and replace them with their values in sIMSPath
		StringTokenizer st = new StringTokenizer(sIMSPathFromRB, "%");
		Environment env = new Environment();
		boolean bTakeThis = false;
		String sMyVar = "";
		String sMailboxPath = "";

		//start with a variable or normal text
		if (sIMSPathFromRB.charAt(0) != '%')
			bTakeThis = true;

		while (st.hasMoreTokens())
		{
			// alternate between variable and text
			if (bTakeThis)
				sIMSPath += st.nextToken();
			else
			{
				sMyVar = st.nextToken();
				if (sMyVar.equals("IMSMAILSERVERUSERNAME"))
				{
					// this is by definition in properties file no system var, it's the username!
					// remember path to mailboxes
					sMailboxPath = sIMSPath;
					sIMSPath += sUserName;
				}
				else
					sIMSPath += env.getEnvVariable(sMyVar);
			}
			bTakeThis = !bTakeThis;
		}

		//check for correct ending of sIMSPath
		if (!sIMSPath.endsWith("/"))
			sIMSPath += "/";

		// test if the path is correct
		File fTest = new File(sMailboxPath);
		if (!(fTest.exists()))
			throw new IOException("Path to folder " + sIMSPath + " not found.");

		return sIMSPath;
	}
}